@@ -31,6 +31,7 @@ class Evaluation:
 
 @dataclasses.dataclass
 class TestCaseConfig:
+    __test__ = False  # See https://docs.pytest.org/en/7.1.x/example/pythoncollection.html#customizing-test-collection
     repeat_num_times: Optional[int] = None
 
 
@@ -89,7 +90,7 @@ class BaseTestEvaluator(abc.ABC):
         pass
 
     @abc.abstractmethod
-    def evaluate_test_case(self, test_case: BaseTestCase, output: Any) -> Evaluation:
+    def evaluate_test_case(self, test_case: BaseTestCase, output: Any) -> Optional[Evaluation]:
         pass
 
 
@@ -112,7 +113,7 @@ class BaseEventEvaluator(abc.ABC):
         pass
 
     @abc.abstractmethod
-    def evaluate_event(self, event: TracerEvent) -> Evaluation:
+    def evaluate_event(self, event: TracerEvent) -> Optional[Evaluation]:
         pass
 
 
