@@ -2,6 +2,7 @@ import asyncio
 import logging
 import os
 import urllib.parse
+from concurrent.futures import Future
 from enum import Enum
 from typing import Any
 from typing import Coroutine
@@ -12,6 +13,9 @@ from typing import Union
 log = logging.getLogger(__name__)
 
 
+AnyTask = Union[asyncio.Task[Any], Future[Any]]
+
+
 class StrEnum(str, Enum):
     def __str__(self) -> str:
         # https://stackoverflow.com/a/74440069
